@@ -9,7 +9,7 @@ def calculate(num1,num2,operating = 'addition',mode = 'int',roundTo = 0):
             num2 = float(num2)
             return num1 + num2
         elif mode == 'round':
-            return round((num1 + num2),roundTo)
+            return round((num1 + num2),int(roundTo))
         else:
             raise TypeError('The error mode')
     elif operating == 'subtraction' or operating == 'sub' or operating == '-':
@@ -20,7 +20,7 @@ def calculate(num1,num2,operating = 'addition',mode = 'int',roundTo = 0):
             num2 = float(num2)
             return num1 - num2
         elif mode == 'round':
-            return round((num1 - num2),roundTo)
+            return round((num1 - num2),int(roundTo))
         else:
             raise TypeError('The error mode')
     elif operating == 'multiplication' or operating == 'mul' or operating == '*':
@@ -31,7 +31,7 @@ def calculate(num1,num2,operating = 'addition',mode = 'int',roundTo = 0):
             num2 = float(num2)
             return num1 * num2
         elif mode == 'round':
-            return round((num1 * num2),roundTo)
+            return round((num1 * num2),int(roundTo))
         else:
             raise TypeError('The error mode')
     elif operating == 'division' or operating == 'div' or operating == '/':
@@ -42,7 +42,7 @@ def calculate(num1,num2,operating = 'addition',mode = 'int',roundTo = 0):
             num2 = float(num2)
             return num1 / num2
         elif mode == 'round':
-            return round((num1 / num2),roundTo)
+            return round((num1 / num2),int(roundTo))
         else:
             raise TypeError('The error mode')
     else:
